@@ -6,6 +6,14 @@ def f():
     # isort: on
 
 
+def f():
+    # ruff: isort: off
+    import sys
+    import os
+    import collections
+    # ruff: isort: on
+
+
 def f():
     import sys
     import os  # isort: skip
