@@ -2,14 +2,14 @@ use anyhow::{bail, Result};
 use rustpython_parser::ast::Stmt;
 use rustpython_parser::{lexer, Mode, Tok};
 
-use crate::ast::types::Range;
-use crate::fix::Fix;
-use crate::source_code::Locator;
+use ruff_diagnostics::Fix;
+use ruff_python_ast::source_code::Locator;
+use ruff_python_ast::types::Range;
 
 /// ANN204
 pub fn add_return_none_annotation(locator: &Locator, stmt: &Stmt) -> Result<Fix> {
-    let range = Range::from_located(stmt);
-    let contents = locator.slice(&range);
+    let range = Range::from(stmt);
+    let contents = locator.slice(range);
 
     // Find the colon (following the `def` keyword).
     let mut seen_lpar = false;
