@@ -1,44 +1,46 @@
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Constant, Expr, ExprKind, Stmt};
 
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::ReturnStatementVisitor;
+use ruff_python_ast::types::Range;
+use ruff_python_ast::visibility;
+use ruff_python_ast::visibility::Visibility;
+use ruff_python_ast::visitor::Visitor;
+use ruff_python_ast::{cast, helpers};
+
+use crate::checkers::ast::Checker;
+use crate::docstrings::definition::{Definition, DefinitionKind};
+use crate::registry::{AsRule, Rule};
+
 use super::fixes;
 use super::helpers::match_function_def;
-use crate::ast::helpers::ReturnStatementVisitor;
-use crate::ast::types::Range;
-use crate::ast::visitor::Visitor;
-use crate::ast::{cast, helpers};
-use crate::checkers::ast::Checker;
-use crate::docstrings::definition::{Definition, DefinitionKind};
-use crate::registry::{Diagnostic, Rule};
-use crate::violation::{AlwaysAutofixableViolation, Violation};
-use crate::visibility;
-use crate::visibility::Visibility;
 
-define_violation!(
-    /// ## What it does
-    /// Checks that function arguments have type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the types of function arguments. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any provided arguments match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// def foo(x):
-    ///     ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def foo(x: int):
-    ///     ...
-    /// ```
-    pub struct MissingTypeFunctionArgument {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that function arguments have type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the types of function arguments. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any provided arguments match expectation.
+///
+/// ## Example
+/// ```python
+/// def foo(x):
+///     ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def foo(x: int):
+///     ...
+/// ```
+#[violation]
+pub struct MissingTypeFunctionArgument {
+    pub name: String,
+}
+
 impl Violation for MissingTypeFunctionArgument {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -47,30 +49,30 @@ impl Violation for MissingTypeFunctionArgument {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that function `*args` arguments have type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the types of function arguments. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any provided arguments match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// def foo(*args):
-    ///     ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def foo(*args: int):
-    ///     ...
-    /// ```
-    pub struct MissingTypeArgs {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that function `*args` arguments have type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the types of function arguments. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any provided arguments match expectation.
+///
+/// ## Example
+/// ```python
+/// def foo(*args):
+///     ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def foo(*args: int):
+///     ...
+/// ```
+#[violation]
+pub struct MissingTypeArgs {
+    pub name: String,
+}
+
 impl Violation for MissingTypeArgs {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -79,30 +81,30 @@ impl Violation for MissingTypeArgs {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that function `**kwargs` arguments have type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the types of function arguments. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any provided arguments match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// def foo(**kwargs):
-    ///     ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def foo(**kwargs: int):
-    ///     ...
-    /// ```
-    pub struct MissingTypeKwargs {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that function `**kwargs` arguments have type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the types of function arguments. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any provided arguments match expectation.
+///
+/// ## Example
+/// ```python
+/// def foo(**kwargs):
+///     ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def foo(**kwargs: int):
+///     ...
+/// ```
+#[violation]
+pub struct MissingTypeKwargs {
+    pub name: String,
+}
+
 impl Violation for MissingTypeKwargs {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -111,35 +113,35 @@ impl Violation for MissingTypeKwargs {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that instance method `self` arguments have type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the types of function arguments. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any provided arguments match expectation.
-    ///
-    /// Note that many type checkers will infer the type of `self` automatically, so this
-    /// annotation is not strictly necessary.
-    ///
-    /// ## Example
-    /// ```python
-    /// class Foo:
-    ///     def bar(self):
-    ///         ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Foo:
-    ///     def bar(self: "Foo"):
-    ///         ...
-    /// ```
-    pub struct MissingTypeSelf {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that instance method `self` arguments have type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the types of function arguments. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any provided arguments match expectation.
+///
+/// Note that many type checkers will infer the type of `self` automatically, so this
+/// annotation is not strictly necessary.
+///
+/// ## Example
+/// ```python
+/// class Foo:
+///     def bar(self):
+///         ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo:
+///     def bar(self: "Foo"):
+///         ...
+/// ```
+#[violation]
+pub struct MissingTypeSelf {
+    pub name: String,
+}
+
 impl Violation for MissingTypeSelf {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -148,37 +150,37 @@ impl Violation for MissingTypeSelf {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that class method `cls` arguments have type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the types of function arguments. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any provided arguments match expectation.
-    ///
-    /// Note that many type checkers will infer the type of `cls` automatically, so this
-    /// annotation is not strictly necessary.
-    ///
-    /// ## Example
-    /// ```python
-    /// class Foo:
-    ///     @classmethod
-    ///     def bar(cls):
-    ///         ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Foo:
-    ///     @classmethod
-    ///     def bar(cls: Type["Foo"]):
-    ///         ...
-    /// ```
-    pub struct MissingTypeCls {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that class method `cls` arguments have type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the types of function arguments. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any provided arguments match expectation.
+///
+/// Note that many type checkers will infer the type of `cls` automatically, so this
+/// annotation is not strictly necessary.
+///
+/// ## Example
+/// ```python
+/// class Foo:
+///     @classmethod
+///     def bar(cls):
+///         ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo:
+///     @classmethod
+///     def bar(cls: Type["Foo"]):
+///         ...
+/// ```
+#[violation]
+pub struct MissingTypeCls {
+    pub name: String,
+}
+
 impl Violation for MissingTypeCls {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -187,30 +189,30 @@ impl Violation for MissingTypeCls {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that public functions and methods have return type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the return types of functions. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any returned values, and the types expected by callers, match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// def add(a, b):
-    ///     return a + b
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def add(a: int, b: int) -> int:
-    ///     return a + b
-    /// ```
-    pub struct MissingReturnTypePublicFunction {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that public functions and methods have return type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the return types of functions. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any returned values, and the types expected by callers, match expectation.
+///
+/// ## Example
+/// ```python
+/// def add(a, b):
+///     return a + b
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def add(a: int, b: int) -> int:
+///     return a + b
+/// ```
+#[violation]
+pub struct MissingReturnTypePublicFunction {
+    pub name: String,
+}
+
 impl Violation for MissingReturnTypePublicFunction {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -219,30 +221,30 @@ impl Violation for MissingReturnTypePublicFunction {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that private functions and methods have return type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the return types of functions. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any returned values, and the types expected by callers, match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// def _add(a, b):
-    ///     return a + b
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def _add(a: int, b: int) -> int:
-    ///     return a + b
-    /// ```
-    pub struct MissingReturnTypePrivateFunction {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that private functions and methods have return type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the return types of functions. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any returned values, and the types expected by callers, match expectation.
+///
+/// ## Example
+/// ```python
+/// def _add(a, b):
+///     return a + b
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def _add(a: int, b: int) -> int:
+///     return a + b
+/// ```
+#[violation]
+pub struct MissingReturnTypePrivateFunction {
+    pub name: String,
+}
+
 impl Violation for MissingReturnTypePrivateFunction {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -251,43 +253,43 @@ impl Violation for MissingReturnTypePrivateFunction {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that "special" methods, like `__init__`, `__new__`, and `__call__`, have
-    /// return type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the return types of functions. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any returned values, and the types expected by callers, match expectation.
-    ///
-    /// Note that type checkers often allow you to omit the return type annotation for
-    /// `__init__` methods, as long as at least one argument has a type annotation. To
-    /// opt-in to this behavior, use the `mypy-init-return` setting in your `pyproject.toml`
-    /// or `ruff.toml` file:
-    ///
-    /// ```toml
-    /// [tool.ruff.flake8-annotations]
-    /// mypy-init-return = true
-    /// ```
-    ///
-    /// ## Example
-    /// ```python
-    /// class Foo:
-    ///     def __init__(self, x: int):
-    ///         self.x = x
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Foo:
-    ///     def __init__(self, x: int) -> None:
-    ///         self.x = x
-    /// ```
-    pub struct MissingReturnTypeSpecialMethod {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that "special" methods, like `__init__`, `__new__`, and `__call__`, have
+/// return type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the return types of functions. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any returned values, and the types expected by callers, match expectation.
+///
+/// Note that type checkers often allow you to omit the return type annotation for
+/// `__init__` methods, as long as at least one argument has a type annotation. To
+/// opt-in to this behavior, use the `mypy-init-return` setting in your `pyproject.toml`
+/// or `ruff.toml` file:
+///
+/// ```toml
+/// [tool.ruff.flake8-annotations]
+/// mypy-init-return = true
+/// ```
+///
+/// ## Example
+/// ```python
+/// class Foo:
+///     def __init__(self, x: int):
+///         self.x = x
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo:
+///     def __init__(self, x: int) -> None:
+///         self.x = x
+/// ```
+#[violation]
+pub struct MissingReturnTypeSpecialMethod {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for MissingReturnTypeSpecialMethod {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -300,34 +302,34 @@ impl AlwaysAutofixableViolation for MissingReturnTypeSpecialMethod {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that static methods have return type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the return types of functions. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any returned values, and the types expected by callers, match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// class Foo:
-    ///     @staticmethod
-    ///     def bar():
-    ///         return 1
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Foo:
-    ///     @staticmethod
-    ///     def bar() -> int:
-    ///         return 1
-    /// ```
-    pub struct MissingReturnTypeStaticMethod {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that static methods have return type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the return types of functions. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any returned values, and the types expected by callers, match expectation.
+///
+/// ## Example
+/// ```python
+/// class Foo:
+///     @staticmethod
+///     def bar():
+///         return 1
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo:
+///     @staticmethod
+///     def bar() -> int:
+///         return 1
+/// ```
+#[violation]
+pub struct MissingReturnTypeStaticMethod {
+    pub name: String,
+}
+
 impl Violation for MissingReturnTypeStaticMethod {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -336,34 +338,34 @@ impl Violation for MissingReturnTypeStaticMethod {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that class methods have return type annotations.
-    ///
-    /// ## Why is this bad?
-    /// Type annotations are a good way to document the return types of functions. They also
-    /// help catch bugs, when used alongside a type checker, by ensuring that the types of
-    /// any returned values, and the types expected by callers, match expectation.
-    ///
-    /// ## Example
-    /// ```python
-    /// class Foo:
-    ///     @classmethod
-    ///     def bar(cls):
-    ///         return 1
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// class Foo:
-    ///     @classmethod
-    ///     def bar(cls) -> int:
-    ///         return 1
-    /// ```
-    pub struct MissingReturnTypeClassMethod {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that class methods have return type annotations.
+///
+/// ## Why is this bad?
+/// Type annotations are a good way to document the return types of functions. They also
+/// help catch bugs, when used alongside a type checker, by ensuring that the types of
+/// any returned values, and the types expected by callers, match expectation.
+///
+/// ## Example
+/// ```python
+/// class Foo:
+///     @classmethod
+///     def bar(cls):
+///         return 1
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo:
+///     @classmethod
+///     def bar(cls) -> int:
+///         return 1
+/// ```
+#[violation]
+pub struct MissingReturnTypeClassMethod {
+    pub name: String,
+}
+
 impl Violation for MissingReturnTypeClassMethod {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -372,39 +374,39 @@ impl Violation for MissingReturnTypeClassMethod {
     }
 }
 
-define_violation!(
-    /// ## What it does
-    /// Checks that an expression is annotated with a more specific type than
-    /// `Any`.
-    ///
-    /// ## Why is this bad?
-    /// `Any` is a special type indicating an unconstrained type. When an
-    /// expression is annotated with type `Any`, type checkers will allow all
-    /// operations on it.
-    ///
-    /// It's better to be explicit about the type of an expression, and to use
-    /// `Any` as an "escape hatch" only when it is really needed.
-    ///
-    /// ## Example
-    /// ```python
-    /// def foo(x: Any):
-    ///     ...
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def foo(x: int):
-    ///     ...
-    /// ```
-    ///
-    /// ## References
-    /// - [PEP 484](https://www.python.org/dev/peps/pep-0484/#the-any-type)
-    /// - [`typing.Any`](https://docs.python.org/3/library/typing.html#typing.Any)
-    /// - [Mypy: The Any type](https://mypy.readthedocs.io/en/stable/kinds_of_types.html#the-any-type)
-    pub struct AnyType {
-        pub name: String,
-    }
-);
+/// ## What it does
+/// Checks that an expression is annotated with a more specific type than
+/// `Any`.
+///
+/// ## Why is this bad?
+/// `Any` is a special type indicating an unconstrained type. When an
+/// expression is annotated with type `Any`, type checkers will allow all
+/// operations on it.
+///
+/// It's better to be explicit about the type of an expression, and to use
+/// `Any` as an "escape hatch" only when it is really needed.
+///
+/// ## Example
+/// ```python
+/// def foo(x: Any):
+///     ...
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def foo(x: int):
+///     ...
+/// ```
+///
+/// ## References
+/// - [PEP 484](https://www.python.org/dev/peps/pep-0484/#the-any-type)
+/// - [`typing.Any`](https://docs.python.org/3/library/typing.html#typing.Any)
+/// - [Mypy: The Any type](https://mypy.readthedocs.io/en/stable/kinds_of_types.html#the-any-type)
+#[violation]
+pub struct AnyType {
+    pub name: String,
+}
+
 impl Violation for AnyType {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -441,10 +443,10 @@ fn check_dynamically_typed<F>(
 ) where
     F: FnOnce() -> String,
 {
-    if checker.match_typing_expr(annotation, "Any") {
+    if checker.ctx.match_typing_expr(annotation, "Any") {
         diagnostics.push(Diagnostic::new(
             AnyType { name: func() },
-            Range::from_located(annotation),
+            Range::from(annotation),
         ));
     };
 }
@@ -482,7 +484,8 @@ pub fn definition(
             .skip(
                 // If this is a non-static method, skip `cls` or `self`.
                 usize::from(
-                    is_method && !visibility::is_staticmethod(checker, cast::decorator_list(stmt)),
+                    is_method
+                        && !visibility::is_staticmethod(&checker.ctx, cast::decorator_list(stmt)),
                 ),
             )
         {
@@ -510,7 +513,7 @@ pub fn definition(
                             MissingTypeFunctionArgument {
                                 name: arg.node.arg.to_string(),
                             },
-                            Range::from_located(arg),
+                            Range::from(arg),
                         ));
                     }
                 }
@@ -541,7 +544,7 @@ pub fn definition(
                             MissingTypeArgs {
                                 name: arg.node.arg.to_string(),
                             },
-                            Range::from_located(arg),
+                            Range::from(arg),
                         ));
                     }
                 }
@@ -572,7 +575,7 @@ pub fn definition(
                             MissingTypeKwargs {
                                 name: arg.node.arg.to_string(),
                             },
-                            Range::from_located(arg),
+                            Range::from(arg),
                         ));
                     }
                 }
@@ -580,16 +583,16 @@ pub fn definition(
         }
 
         // ANN101, ANN102
-        if is_method && !visibility::is_staticmethod(checker, cast::decorator_list(stmt)) {
+        if is_method && !visibility::is_staticmethod(&checker.ctx, cast::decorator_list(stmt)) {
             if let Some(arg) = args.posonlyargs.first().or_else(|| args.args.first()) {
                 if arg.node.annotation.is_none() {
-                    if visibility::is_classmethod(checker, cast::decorator_list(stmt)) {
+                    if visibility::is_classmethod(&checker.ctx, cast::decorator_list(stmt)) {
                         if checker.settings.rules.enabled(&Rule::MissingTypeCls) {
                             diagnostics.push(Diagnostic::new(
                                 MissingTypeCls {
                                     name: arg.node.arg.to_string(),
                                 },
-                                Range::from_located(arg),
+                                Range::from(arg),
                             ));
                         }
                     } else {
@@ -598,7 +601,7 @@ pub fn definition(
                                 MissingTypeSelf {
                                     name: arg.node.arg.to_string(),
                                 },
-                                Range::from_located(arg),
+                                Range::from(arg),
                             ));
                         }
                     }
@@ -619,7 +622,7 @@ pub fn definition(
             // (explicitly or implicitly).
             checker.settings.flake8_annotations.suppress_none_returning && is_none_returning(body)
         ) {
-            if is_method && visibility::is_classmethod(checker, cast::decorator_list(stmt)) {
+            if is_method && visibility::is_classmethod(&checker.ctx, cast::decorator_list(stmt)) {
                 if checker
                     .settings
                     .rules
@@ -632,7 +635,8 @@ pub fn definition(
                         helpers::identifier_range(stmt, checker.locator),
                     ));
                 }
-            } else if is_method && visibility::is_staticmethod(checker, cast::decorator_list(stmt))
+            } else if is_method
+                && visibility::is_staticmethod(&checker.ctx, cast::decorator_list(stmt))
             {
                 if checker
                     .settings
