@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::Expr;
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct UselessContextlibSuppress;
 
-define_violation!(
-    pub struct UselessContextlibSuppress;
-);
 impl Violation for UselessContextlibSuppress {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -19,16 +19,19 @@ impl Violation for UselessContextlibSuppress {
     }
 }
 
-/// B005
+/// B022
 pub fn useless_contextlib_suppress(checker: &mut Checker, expr: &Expr, func: &Expr, args: &[Expr]) {
     if args.is_empty()
-        && checker.resolve_call_path(func).map_or(false, |call_path| {
-            call_path.as_slice() == ["contextlib", "suppress"]
-        })
+        && checker
+            .ctx
+            .resolve_call_path(func)
+            .map_or(false, |call_path| {
+                call_path.as_slice() == ["contextlib", "suppress"]
+            })
     {
         checker.diagnostics.push(Diagnostic::new(
             UselessContextlibSuppress,
-            Range::from_located(expr),
+            Range::from(expr),
         ));
     }
 }
