@@ -1,14 +1,15 @@
 use itertools::Itertools;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::lexer::{LexResult, Spanned};
 use rustpython_parser::Tok;
 
-use crate::ast::types::Range;
-use crate::fix::Fix;
-use crate::registry::{Diagnostic, Rule};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Violation};
+use ruff_diagnostics::{Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::source_code::Locator;
+use ruff_python_ast::types::Range;
+
+use crate::registry::Rule;
 use crate::settings::{flags, Settings};
-use crate::source_code::Locator;
-use crate::violation::{AlwaysAutofixableViolation, Violation};
 
 /// Simplified token type.
 #[derive(Copy, Clone, PartialEq, Eq)]
@@ -109,9 +110,9 @@ impl Context {
     }
 }
 
-define_violation!(
-    pub struct TrailingCommaMissing;
-);
+#[violation]
+pub struct TrailingCommaMissing;
+
 impl AlwaysAutofixableViolation for TrailingCommaMissing {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -123,9 +124,9 @@ impl AlwaysAutofixableViolation for TrailingCommaMissing {
     }
 }
 
-define_violation!(
-    pub struct TrailingCommaOnBareTupleProhibited;
-);
+#[violation]
+pub struct TrailingCommaOnBareTupleProhibited;
+
 impl Violation for TrailingCommaOnBareTupleProhibited {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -133,9 +134,9 @@ impl Violation for TrailingCommaOnBareTupleProhibited {
     }
 }
 
-define_violation!(
-    pub struct TrailingCommaProhibited;
-);
+#[violation]
+pub struct TrailingCommaProhibited;
+
 impl AlwaysAutofixableViolation for TrailingCommaProhibited {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -308,7 +309,7 @@ pub fn trailing_commas(
                 // rather than just inserting a comma at the end. This prevents the UP034 autofix
                 // removing any brackets in the same linter pass - doing both at the same time could
                 // lead to a syntax error.
-                let contents = locator.slice(&Range::new(missing_comma.0, missing_comma.2));
+                let contents = locator.slice(Range::new(missing_comma.0, missing_comma.2));
                 diagnostic.amend(Fix::replacement(
                     format!("{contents},"),
                     missing_comma.0,
