@@ -1,35 +1,34 @@
 use std::path::{Path, PathBuf};
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::fs;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
 
-define_violation!(
-    /// ## What it does
-    /// Checks for packages that are missing an `__init__.py` file.
-    ///
-    /// ## Why is this bad?
-    /// Python packages are directories that contain a file named `__init__.py`.
-    /// The existence of this file indicates that the directory is a Python
-    /// package, and so it can be imported the same way a module can be
-    /// imported.
-    ///
-    /// Directories that lack an `__init__.py` file can still be imported, but
-    /// they're indicative of a special kind of package, known as a "namespace
-    /// package" (see: [PEP 420](https://www.python.org/dev/peps/pep-0420/)).
-    /// Namespace packages are less widely used, so a package that lacks an
-    /// `__init__.py` file is typically meant to be a regular package, and
-    /// the absence of the `__init__.py` file is probably an oversight.
-    ///
-    /// ## Options
-    /// * `namespace-packages`
-    pub struct ImplicitNamespacePackage {
-        pub filename: String,
-    }
-);
+/// ## What it does
+/// Checks for packages that are missing an `__init__.py` file.
+///
+/// ## Why is this bad?
+/// Python packages are directories that contain a file named `__init__.py`.
+/// The existence of this file indicates that the directory is a Python
+/// package, and so it can be imported the same way a module can be
+/// imported.
+///
+/// Directories that lack an `__init__.py` file can still be imported, but
+/// they're indicative of a special kind of package, known as a "namespace
+/// package" (see: [PEP 420](https://www.python.org/dev/peps/pep-0420/)).
+/// Namespace packages are less widely used, so a package that lacks an
+/// `__init__.py` file is typically meant to be a regular package, and
+/// the absence of the `__init__.py` file is probably an oversight.
+///
+/// ## Options
+/// - `namespace-packages`
+#[violation]
+pub struct ImplicitNamespacePackage {
+    pub filename: String,
+}
+
 impl Violation for ImplicitNamespacePackage {
     #[derive_message_formats]
     fn message(&self) -> String {
