@@ -1,3 +1,4 @@
+pub use bad_version_info_comparison::{bad_version_info_comparison, BadVersionInfoComparison};
 pub use docstring_in_stubs::{docstring_in_stubs, DocstringInStub};
 pub use non_empty_stub_body::{non_empty_stub_body, NonEmptyStubBody};
 pub use pass_statement_stub_body::{pass_statement_stub_body, PassStatementStubBody};
@@ -6,14 +7,16 @@ pub use simple_defaults::{
     argument_simple_defaults, typed_argument_simple_defaults, ArgumentSimpleDefaults,
     TypedArgumentSimpleDefaults,
 };
+pub use type_comment_in_stub::{type_comment_in_stub, TypeCommentInStub};
 pub use unrecognized_platform::{
     unrecognized_platform, UnrecognizedPlatformCheck, UnrecognizedPlatformName,
 };
 
+mod bad_version_info_comparison;
 mod docstring_in_stubs;
 mod non_empty_stub_body;
 mod pass_statement_stub_body;
 mod prefix_type_params;
-mod unrecognized_platform;
-
 mod simple_defaults;
+mod type_comment_in_stub;
+mod unrecognized_platform;
