@@ -2,19 +2,19 @@ use log::error;
 use rustc_hash::FxHashSet;
 use rustpython_parser::ast::{Cmpop, Constant, Expr, ExprContext, ExprKind, Stmt, StmtKind};
 
-use ruff_macros::{define_violation, derive_message_formats};
-
-use crate::ast::comparable::{ComparableConstant, ComparableExpr, ComparableStmt};
-use crate::ast::helpers::{
+use ruff_diagnostics::{AutofixKind, Availability, Diagnostic, Fix, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::comparable::{ComparableConstant, ComparableExpr, ComparableStmt};
+use ruff_python_ast::helpers::{
     contains_call_path, contains_effect, create_expr, create_stmt, first_colon_range, has_comments,
     has_comments_in, unparse_expr, unparse_stmt,
 };
-use crate::ast::types::Range;
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
+use crate::registry::AsRule;
 use crate::rules::flake8_simplify::rules::fix_if;
-use crate::violation::{AutofixKind, Availability, Violation};
 
 fn compare_expr(expr1: &ComparableExpr, expr2: &ComparableExpr) -> bool {
     expr1.eq(expr2)
@@ -34,11 +34,11 @@ fn compare_body(body1: &[Stmt], body2: &[Stmt]) -> bool {
         .all(|(stmt1, stmt2)| compare_stmt(&stmt1.into(), &stmt2.into()))
 }
 
-define_violation!(
-    pub struct CollapsibleIf {
-        pub fixable: bool,
-    }
-);
+#[violation]
+pub struct CollapsibleIf {
+    pub fixable: bool,
+}
+
 impl Violation for CollapsibleIf {
     const AUTOFIX: Option<AutofixKind> = Some(AutofixKind::new(Availability::Sometimes));
 
@@ -53,12 +53,12 @@ impl Violation for CollapsibleIf {
     }
 }
 
-define_violation!(
-    pub struct NeedlessBool {
-        pub condition: String,
-        pub fixable: bool,
-    }
-);
+#[violation]
+pub struct NeedlessBool {
+    pub condition: String,
+    pub fixable: bool,
+}
+
 impl Violation for NeedlessBool {
     const AUTOFIX: Option<AutofixKind> = Some(AutofixKind::new(Availability::Sometimes));
 
@@ -75,29 +75,29 @@ impl Violation for NeedlessBool {
     }
 }
 
-define_violation!(
-    /// ### What it does
-    /// Checks for three or more consecutive if-statements with direct returns
-    ///
-    /// ### Why is this bad?
-    /// These can be simplified by using a dictionary
-    ///
-    /// ### Example
-    /// ```python
-    /// if x == 1:
-    ///     return "Hello"
-    /// elif x == 2:
-    ///     return "Goodbye"
-    /// else:
-    ///    return "Goodnight"
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// return {1: "Hello", 2: "Goodbye"}.get(x, "Goodnight")
-    /// ```
-    pub struct ManualDictLookup;
-);
+/// ## What it does
+/// Checks for three or more consecutive if-statements with direct returns
+///
+/// ## Why is this bad?
+/// These can be simplified by using a dictionary
+///
+/// ## Example
+/// ```python
+/// if x == 1:
+///     return "Hello"
+/// elif x == 2:
+///     return "Goodbye"
+/// else:
+///     return "Goodnight"
+/// ```
+///
+/// Use instead:
+/// ```python
+/// return {1: "Hello", 2: "Goodbye"}.get(x, "Goodnight")
+/// ```
+#[violation]
+pub struct ManualDictLookup;
+
 impl Violation for ManualDictLookup {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -105,12 +105,12 @@ impl Violation for ManualDictLookup {
     }
 }
 
-define_violation!(
-    pub struct UseTernaryOperator {
-        pub contents: String,
-        pub fixable: bool,
-    }
-);
+#[violation]
+pub struct UseTernaryOperator {
+    pub contents: String,
+    pub fixable: bool,
+}
+
 impl Violation for UseTernaryOperator {
     const AUTOFIX: Option<AutofixKind> = Some(AutofixKind::new(Availability::Sometimes));
 
@@ -128,29 +128,29 @@ impl Violation for UseTernaryOperator {
     }
 }
 
-define_violation!(
-    /// ### What it does
-    /// Checks for `if` branches with identical arm bodies.
-    ///
-    /// ### Why is this bad?
-    /// If multiple arms of an `if` statement have the same body, using `or`
-    /// better signals the intent of the statement.
-    ///
-    /// ### Example
-    /// ```python
-    /// if x == 1:
-    ///     print("Hello")
-    /// elif x == 2:
-    ///     print("Hello")
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// if x == 1 or x == 2:
-    ///     print("Hello")
-    /// ```
-    pub struct IfWithSameArms;
-);
+/// ## What it does
+/// Checks for `if` branches with identical arm bodies.
+///
+/// ## Why is this bad?
+/// If multiple arms of an `if` statement have the same body, using `or`
+/// better signals the intent of the statement.
+///
+/// ## Example
+/// ```python
+/// if x == 1:
+///     print("Hello")
+/// elif x == 2:
+///     print("Hello")
+/// ```
+///
+/// Use instead:
+/// ```python
+/// if x == 1 or x == 2:
+///     print("Hello")
+/// ```
+#[violation]
+pub struct IfWithSameArms;
+
 impl Violation for IfWithSameArms {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -158,12 +158,12 @@ impl Violation for IfWithSameArms {
     }
 }
 
-define_violation!(
-    pub struct DictGetWithDefault {
-        pub contents: String,
-        pub fixable: bool,
-    }
-);
+#[violation]
+pub struct DictGetWithDefault {
+    pub contents: String,
+    pub fixable: bool,
+}
+
 impl Violation for DictGetWithDefault {
     const AUTOFIX: Option<AutofixKind> = Some(AutofixKind::new(Availability::Sometimes));
 
@@ -275,7 +275,7 @@ pub fn nested_if_statements(
     let mut diagnostic = Diagnostic::new(
         CollapsibleIf { fixable },
         colon.map_or_else(
-            || Range::from_located(stmt),
+            || Range::from(stmt),
             |colon| Range::new(stmt.location, colon.end_location),
         ),
     );
@@ -284,7 +284,7 @@ pub fn nested_if_statements(
             Ok(fix) => {
                 if fix
                     .content
-                    .lines()
+                    .universal_newlines()
                     .all(|line| line.len() <= checker.settings.line_length)
                 {
                     diagnostic.amend(fix);
@@ -347,12 +347,9 @@ pub fn needless_bool(checker: &mut Checker, stmt: &Stmt) {
     let fixable = matches!(if_return, Bool::True)
         && matches!(else_return, Bool::False)
         && !has_comments(stmt, checker.locator)
-        && (matches!(test.node, ExprKind::Compare { .. }) || checker.is_builtin("bool"));
+        && (matches!(test.node, ExprKind::Compare { .. }) || checker.ctx.is_builtin("bool"));
 
-    let mut diagnostic = Diagnostic::new(
-        NeedlessBool { condition, fixable },
-        Range::from_located(stmt),
-    );
+    let mut diagnostic = Diagnostic::new(NeedlessBool { condition, fixable }, Range::from(stmt));
     if fixable && checker.patch(diagnostic.kind.rule()) {
         if matches!(test.node, ExprKind::Compare { .. }) {
             // If the condition is a comparison, we can replace it with the condition.
@@ -431,13 +428,13 @@ pub fn use_ternary_operator(checker: &mut Checker, stmt: &Stmt, parent: Option<&
     }
 
     // Avoid suggesting ternary for `if sys.version_info >= ...`-style checks.
-    if contains_call_path(checker, test, &["sys", "version_info"]) {
+    if contains_call_path(&checker.ctx, test, &["sys", "version_info"]) {
         return;
     }
 
     // Avoid suggesting ternary for `if sys.platform.startswith("...")`-style
     // checks.
-    if contains_call_path(checker, test, &["sys", "platform"]) {
+    if contains_call_path(&checker.ctx, test, &["sys", "platform"]) {
         return;
     }
 
@@ -501,7 +498,7 @@ pub fn use_ternary_operator(checker: &mut Checker, stmt: &Stmt, parent: Option<&
             contents: contents.clone(),
             fixable,
         },
-        Range::from_located(stmt),
+        Range::from(stmt),
     );
     if fixable && checker.patch(diagnostic.kind.rule()) {
         diagnostic.amend(Fix::replacement(
@@ -592,6 +589,7 @@ pub fn manual_dict_lookup(
     test: &Expr,
     body: &[Stmt],
     orelse: &[Stmt],
+    parent: Option<&Stmt>,
 ) {
     // Throughout this rule:
     // * Each if-statement's test must consist of a constant equality check with the same variable.
@@ -628,11 +626,41 @@ pub fn manual_dict_lookup(
     };
     if value
         .as_ref()
-        .map_or(false, |value| contains_effect(checker, value))
+        .map_or(false, |value| contains_effect(&checker.ctx, value))
     {
         return;
     }
 
+    // It's part of a bigger if-elif block:
+    // https://github.com/MartinThoma/flake8-simplify/issues/115
+    if let Some(StmtKind::If {
+        orelse: parent_orelse,
+        ..
+    }) = parent.map(|parent| &parent.node)
+    {
+        if parent_orelse.len() == 1 && stmt == &parent_orelse[0] {
+            // TODO(charlie): These two cases have the same AST:
+            //
+            // if True:
+            //     pass
+            // elif a:
+            //     b = 1
+            // else:
+            //     b = 2
+            //
+            // if True:
+            //     pass
+            // else:
+            //     if a:
+            //         b = 1
+            //     else:
+            //         b = 2
+            //
+            // We want to flag the latter, but not the former. Right now, we flag neither.
+            return;
+        }
+    }
+
     let mut constants: FxHashSet<ComparableConstant> = FxHashSet::default();
     constants.insert(constant.into());
 
@@ -671,7 +699,7 @@ pub fn manual_dict_lookup(
         };
         if value
             .as_ref()
-            .map_or(false, |value| contains_effect(checker, value))
+            .map_or(false, |value| contains_effect(&checker.ctx, value))
         {
             return;
         };
@@ -698,7 +726,7 @@ pub fn manual_dict_lookup(
 
     checker
         .diagnostics
-        .push(Diagnostic::new(ManualDictLookup, Range::from_located(stmt)));
+        .push(Diagnostic::new(ManualDictLookup, Range::from(stmt)));
 }
 
 /// SIM401
@@ -753,7 +781,7 @@ pub fn use_dict_get_with_default(
     }
 
     // Check that the default value is not "complex".
-    if contains_effect(checker, default_val) {
+    if contains_effect(&checker.ctx, default_val) {
         return;
     }
 
@@ -818,7 +846,7 @@ pub fn use_dict_get_with_default(
             contents: contents.clone(),
             fixable,
         },
-        Range::from_located(stmt),
+        Range::from(stmt),
     );
     if fixable && checker.patch(diagnostic.kind.rule()) {
         diagnostic.amend(Fix::replacement(
