@@ -1,14 +1,12 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::{Binding, BindingKind, ExecutionContext};
 
-use crate::ast::types::{Binding, BindingKind, ExecutionContext};
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+#[violation]
+pub struct RuntimeImportInTypeCheckingBlock {
+    pub full_name: String,
+}
 
-define_violation!(
-    pub struct RuntimeImportInTypeCheckingBlock {
-        pub full_name: String,
-    }
-);
 impl Violation for RuntimeImportInTypeCheckingBlock {
     #[derive_message_formats]
     fn message(&self) -> String {
