@@ -1,8 +1,10 @@
 use rustpython_parser::ast::Expr;
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, DiagnosticKind};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::{Diagnostic, DiagnosticKind};
+use crate::registry::AsRule;
 use crate::rules::flake8_use_pathlib::violations::{
     PathlibAbspath, PathlibBasename, PathlibChmod, PathlibDirname, PathlibExists,
     PathlibExpanduser, PathlibGetcwd, PathlibIsAbs, PathlibIsDir, PathlibIsFile, PathlibIsLink,
@@ -15,6 +17,7 @@ use crate::settings::types::PythonVersion;
 pub fn replaceable_by_pathlib(checker: &mut Checker, expr: &Expr) {
     if let Some(diagnostic_kind) =
         checker
+            .ctx
             .resolve_call_path(expr)
             .and_then(|call_path| match call_path.as_slice() {
                 ["os", "path", "abspath"] => Some(PathlibAbspath.into()),
@@ -49,8 +52,7 @@ pub fn replaceable_by_pathlib(checker: &mut Checker, expr: &Expr) {
                 _ => None,
             })
     {
-        let diagnostic =
-            Diagnostic::new::<DiagnosticKind>(diagnostic_kind, Range::from_located(expr));
+        let diagnostic = Diagnostic::new::<DiagnosticKind>(diagnostic_kind, Range::from(expr));
 
         if checker.settings.rules.enabled(diagnostic.kind.rule()) {
             checker.diagnostics.push(diagnostic);
