@@ -1,19 +1,19 @@
 use rustpython_parser::ast::{Location, Stmt};
-use rustpython_parser::lexer;
-use rustpython_parser::lexer::Tok;
+use rustpython_parser::{lexer, Mode, Tok};
+
+use ruff_python_ast::helpers::is_docstring_stmt;
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::source_code::Locator;
 
 use super::types::TrailingComma;
-use crate::ast::helpers::is_docstring_stmt;
-use crate::ast::types::Range;
-use crate::source_code::Locator;
 
 /// Return `true` if a `StmtKind::ImportFrom` statement ends with a magic
 /// trailing comma.
 pub fn trailing_comma(stmt: &Stmt, locator: &Locator) -> TrailingComma {
-    let contents = locator.slice(&Range::from_located(stmt));
+    let contents = locator.slice(stmt);
     let mut count: usize = 0;
     let mut trailing_comma = TrailingComma::Absent;
-    for (_, tok, _) in lexer::make_tokenizer(contents).flatten() {
+    for (_, tok, _) in lexer::lex_located(contents, Mode::Module, stmt.location).flatten() {
         if matches!(tok, Tok::Lpar) {
             count += 1;
         }
@@ -63,7 +63,7 @@ pub fn has_comment_break(stmt: &Stmt, locator: &Locator) -> bool {
     //   # Direct comment.
     //   def f(): pass
     let mut seen_blank = false;
-    for line in locator.take(stmt.location).lines().rev() {
+    for line in locator.take(stmt.location).universal_newlines().rev() {
         let line = line.trim();
         if seen_blank {
             if line.starts_with('#') {
@@ -110,7 +110,7 @@ pub fn find_splice_location(body: &[Stmt], locator: &Locator) -> Location {
 
     // Find the first token that isn't a comment or whitespace.
     let contents = locator.skip(splice);
-    for (.., tok, end) in lexer::make_tokenizer_located(contents, splice).flatten() {
+    for (.., tok, end) in lexer::lex_located(contents, Mode::Module, splice).flatten() {
         if matches!(tok, Tok::Comment(..) | Tok::Newline) {
             splice = end;
         } else {
@@ -124,11 +124,12 @@ pub fn find_splice_location(body: &[Stmt], locator: &Locator) -> Location {
 #[cfg(test)]
 mod tests {
     use anyhow::Result;
+    use rustpython_parser as parser;
     use rustpython_parser::ast::Location;
-    use rustpython_parser::parser;
+
+    use ruff_python_ast::source_code::Locator;
 
     use super::find_splice_location;
-    use crate::source_code::Locator;
 
     fn splice_contents(contents: &str) -> Result<Location> {
         let program = parser::parse_program(contents, "<filename>")?;
