@@ -1,20 +1,36 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use anyhow::{bail, Result};
+use log::error;
 use rustpython_parser::ast::Location;
 
-use crate::ast::types::Range;
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
-use crate::source_code::Locator;
-use crate::violation::AlwaysAutofixableViolation;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::source_code::Locator;
+use ruff_python_ast::types::Range;
+
+/// ## What it does
+/// Checks for invalid escape sequences.
+///
+/// ## Why is this bad?
+/// Invalid escape sequences are deprecated in Python 3.6.
+///
+/// ## Example
+/// ```python
+/// regex = '\.png$'
+/// ```
+///
+/// Use instead:
+/// ```python
+/// regex = r'\.png$'
+/// ```
+#[violation]
+pub struct InvalidEscapeSequence(pub char);
 
-define_violation!(
-    pub struct InvalidEscapeSequence(pub char);
-);
 impl AlwaysAutofixableViolation for InvalidEscapeSequence {
     #[derive_message_formats]
     fn message(&self) -> String {
         let InvalidEscapeSequence(char) = self;
-        format!("Invalid escape sequence: '\\{char}'")
+        format!("Invalid escape sequence: `\\{char}`")
     }
 
     fn autofix_title(&self) -> String {
@@ -30,14 +46,14 @@ const VALID_ESCAPE_SEQUENCES: &[char; 23] = &[
 ];
 
 /// Return the quotation markers used for a String token.
-fn extract_quote(text: &str) -> &str {
+fn extract_quote(text: &str) -> Result<&str> {
     for quote in ["'''", "\"\"\"", "'", "\""] {
         if text.ends_with(quote) {
-            return quote;
+            return Ok(quote);
         }
     }
 
-    panic!("Unable to find quotation mark for String token")
+    bail!("Unable to find quotation mark for String token")
 }
 
 /// W605
@@ -49,16 +65,19 @@ pub fn invalid_escape_sequence(
 ) -> Vec<Diagnostic> {
     let mut diagnostics = vec![];
 
-    let text = locator.slice_source_code_range(&Range::new(start, end));
+    let text = locator.slice(Range::new(start, end));
 
     // Determine whether the string is single- or triple-quoted.
-    let quote = extract_quote(text);
+    let Ok(quote) = extract_quote(text) else {
+        error!("Unable to find quotation mark for string token");
+        return diagnostics;
+    };
     let quote_pos = text.find(quote).unwrap();
     let prefix = text[..quote_pos].to_lowercase();
     let body = &text[(quote_pos + quote.len())..(text.len() - quote.len())];
 
     if !prefix.contains('r') {
-        for (row_offset, line) in body.lines().enumerate() {
+        for (row_offset, line) in body.universal_newlines().enumerate() {
             let chars: Vec<char> = line.chars().collect();
             for col_offset in 0..chars.len() {
                 if chars[col_offset] != '\\' {
