@@ -1,15 +1,34 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::Location;
 
-use crate::ast::types::Range;
-use crate::fix::Fix;
-use crate::registry::{Diagnostic, Rule};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
+use crate::registry::Rule;
 use crate::settings::{flags, Settings};
-use crate::violation::AlwaysAutofixableViolation;
+
+/// ## What it does
+/// Checks for superfluous trailing whitespace.
+///
+/// ## Why is this bad?
+/// Per PEP 8, "avoid trailing whitespace anywhere. Because it’s usually
+/// invisible, it can be confusing"
+///
+/// ## Example
+/// ```python
+/// spam(1) \n#
+/// ```
+///
+/// Use instead:
+/// ```python
+/// spam(1)\n#
+/// ```
+///
+/// ## References
+/// - [PEP 8](https://peps.python.org/pep-0008/#other-recommendations)
+#[violation]
+pub struct TrailingWhitespace;
 
-define_violation!(
-    pub struct TrailingWhitespace;
-);
 impl AlwaysAutofixableViolation for TrailingWhitespace {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -21,9 +40,29 @@ impl AlwaysAutofixableViolation for TrailingWhitespace {
     }
 }
 
-define_violation!(
-    pub struct BlankLineContainsWhitespace;
-);
+/// ## What it does
+/// Checks for superfluous whitespace in blank lines.
+///
+/// ## Why is this bad?
+/// Per PEP 8, "avoid trailing whitespace anywhere. Because it’s usually
+/// invisible, it can be confusing"
+///
+/// ## Example
+/// ```python
+/// class Foo(object):\n    \n    bang = 12
+///
+/// ```
+///
+/// Use instead:
+/// ```python
+/// class Foo(object):\n\n    bang = 12
+/// ```
+///
+/// ## References
+/// - [PEP 8](https://peps.python.org/pep-0008/#other-recommendations)
+#[violation]
+pub struct BlankLineContainsWhitespace;
+
 impl AlwaysAutofixableViolation for BlankLineContainsWhitespace {
     #[derive_message_formats]
     fn message(&self) -> String {
