@@ -1,18 +1,18 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AutofixKind, Availability, Diagnostic, Fix, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::Docstring;
-use crate::fix::Fix;
 use crate::message::Location;
-use crate::registry::Diagnostic;
-use crate::violation::{AutofixKind, Availability, Violation};
+use crate::registry::AsRule;
+
+#[violation]
+pub struct BlankLineAfterSummary {
+    pub num_lines: usize,
+}
 
-define_violation!(
-    pub struct BlankLineAfterSummary {
-        pub num_lines: usize,
-    }
-);
 fn fmt_blank_line_after_summary_autofix_msg(_: &BlankLineAfterSummary) -> String {
     "Insert single blank line".to_string()
 }
@@ -46,7 +46,7 @@ pub fn blank_after_summary(checker: &mut Checker, docstring: &Docstring) {
 
     let mut lines_count = 1;
     let mut blanks_count = 0;
-    for line in body.trim().lines().skip(1) {
+    for line in body.trim().universal_newlines().skip(1) {
         lines_count += 1;
         if line.trim().is_empty() {
             blanks_count += 1;
@@ -59,13 +59,13 @@ pub fn blank_after_summary(checker: &mut Checker, docstring: &Docstring) {
             BlankLineAfterSummary {
                 num_lines: blanks_count,
             },
-            Range::from_located(docstring.expr),
+            Range::from(docstring.expr),
         );
         if checker.patch(diagnostic.kind.rule()) {
             if blanks_count > 1 {
                 // Find the "summary" line (defined as the first non-blank line).
                 let mut summary_line = 0;
-                for line in body.lines() {
+                for line in body.universal_newlines() {
                     if line.trim().is_empty() {
                         summary_line += 1;
                     } else {
