@@ -1,18 +1,18 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::newlines::StrExt;
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::{DefinitionKind, Docstring};
-use crate::fix::Fix;
 use crate::message::Location;
-use crate::registry::{Diagnostic, Rule};
-use crate::violation::AlwaysAutofixableViolation;
+use crate::registry::{AsRule, Rule};
+
+#[violation]
+pub struct OneBlankLineBeforeClass {
+    pub lines: usize,
+}
 
-define_violation!(
-    pub struct OneBlankLineBeforeClass {
-        pub lines: usize,
-    }
-);
 impl AlwaysAutofixableViolation for OneBlankLineBeforeClass {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -24,11 +24,11 @@ impl AlwaysAutofixableViolation for OneBlankLineBeforeClass {
     }
 }
 
-define_violation!(
-    pub struct OneBlankLineAfterClass {
-        pub lines: usize,
-    }
-);
+#[violation]
+pub struct OneBlankLineAfterClass {
+    pub lines: usize,
+}
+
 impl AlwaysAutofixableViolation for OneBlankLineAfterClass {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -40,11 +40,11 @@ impl AlwaysAutofixableViolation for OneBlankLineAfterClass {
     }
 }
 
-define_violation!(
-    pub struct NoBlankLineBeforeClass {
-        pub lines: usize,
-    }
-);
+#[violation]
+pub struct NoBlankLineBeforeClass {
+    pub lines: usize,
+}
+
 impl AlwaysAutofixableViolation for NoBlankLineBeforeClass {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -71,13 +71,12 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
             .rules
             .enabled(&Rule::NoBlankLineBeforeClass)
     {
-        let (before, ..) = checker.locator.partition_source_code_at(
-            &Range::from_located(parent),
-            &Range::from_located(docstring.expr),
-        );
+        let before = checker
+            .locator
+            .slice(Range::new(parent.location, docstring.expr.location));
 
         let blank_lines_before = before
-            .lines()
+            .universal_newlines()
             .rev()
             .skip(1)
             .take_while(|line| line.trim().is_empty())
@@ -92,7 +91,7 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
                     NoBlankLineBeforeClass {
                         lines: blank_lines_before,
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Delete the blank line before the class.
@@ -114,7 +113,7 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
                     OneBlankLineBeforeClass {
                         lines: blank_lines_before,
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Insert one blank line before the class.
@@ -134,13 +133,13 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
         .rules
         .enabled(&Rule::OneBlankLineAfterClass)
     {
-        let (_, _, after) = checker.locator.partition_source_code_at(
-            &Range::from_located(parent),
-            &Range::from_located(docstring.expr),
-        );
+        let after = checker.locator.slice(Range::new(
+            docstring.expr.end_location.unwrap(),
+            parent.end_location.unwrap(),
+        ));
 
         let all_blank_after = after
-            .lines()
+            .universal_newlines()
             .skip(1)
             .all(|line| line.trim().is_empty() || line.trim_start().starts_with('#'));
         if all_blank_after {
@@ -148,7 +147,7 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
         }
 
         let blank_lines_after = after
-            .lines()
+            .universal_newlines()
             .skip(1)
             .take_while(|line| line.trim().is_empty())
             .count();
@@ -157,7 +156,7 @@ pub fn blank_before_after_class(checker: &mut Checker, docstring: &Docstring) {
                 OneBlankLineAfterClass {
                     lines: blank_lines_after,
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Insert a blank line before the class (replacing any existing lines).
