@@ -1,14 +1,13 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
 
-use crate::ast::types::Range;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::{DefinitionKind, Docstring};
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
 
-define_violation!(
-    pub struct FirstLineCapitalized;
-);
+#[violation]
+pub struct FirstLineCapitalized;
+
 impl Violation for FirstLineCapitalized {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -46,6 +45,6 @@ pub fn capitalized(checker: &mut Checker, docstring: &Docstring) {
     };
     checker.diagnostics.push(Diagnostic::new(
         FirstLineCapitalized,
-        Range::from_located(docstring.expr),
+        Range::from(docstring.expr),
     ));
 }
