@@ -1,18 +1,18 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Violation};
+use ruff_diagnostics::{Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::newlines::NewlineWithTrailingNewline;
+use ruff_python_ast::types::Range;
+use ruff_python_ast::whitespace;
 
-use crate::ast::types::Range;
-use crate::ast::whitespace;
-use crate::ast::whitespace::LinesWithTrailingNewline;
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::Docstring;
-use crate::fix::Fix;
 use crate::message::Location;
-use crate::registry::{Diagnostic, Rule};
-use crate::violation::{AlwaysAutofixableViolation, Violation};
+use crate::registry::{AsRule, Rule};
+
+#[violation]
+pub struct IndentWithSpaces;
 
-define_violation!(
-    pub struct IndentWithSpaces;
-);
 impl Violation for IndentWithSpaces {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -20,9 +20,9 @@ impl Violation for IndentWithSpaces {
     }
 }
 
-define_violation!(
-    pub struct NoUnderIndentation;
-);
+#[violation]
+pub struct NoUnderIndentation;
+
 impl AlwaysAutofixableViolation for NoUnderIndentation {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -34,9 +34,9 @@ impl AlwaysAutofixableViolation for NoUnderIndentation {
     }
 }
 
-define_violation!(
-    pub struct NoOverIndentation;
-);
+#[violation]
+pub struct NoOverIndentation;
+
 impl AlwaysAutofixableViolation for NoOverIndentation {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -53,7 +53,7 @@ pub fn indent(checker: &mut Checker, docstring: &Docstring) {
     let body = docstring.body;
 
     // Split the docstring into lines.
-    let lines: Vec<&str> = LinesWithTrailingNewline::from(body).collect();
+    let lines: Vec<&str> = NewlineWithTrailingNewline::from(body).collect();
     if lines.len() <= 1 {
         return;
     }
@@ -123,7 +123,7 @@ pub fn indent(checker: &mut Checker, docstring: &Docstring) {
         if has_seen_tab {
             checker.diagnostics.push(Diagnostic::new(
                 IndentWithSpaces,
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             ));
         }
     }
