@@ -4,28 +4,28 @@ use regex::Regex;
 use rustc_hash::FxHashSet;
 use rustpython_parser::ast::StmtKind;
 
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Violation};
+use ruff_diagnostics::{Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::identifier_range;
+use ruff_python_ast::newlines::NewlineWithTrailingNewline;
+use ruff_python_ast::types::Range;
+use ruff_python_ast::visibility::is_staticmethod;
+use ruff_python_ast::{cast, whitespace};
 
-use crate::ast::helpers::identifier_range;
-use crate::ast::types::Range;
-use crate::ast::whitespace::LinesWithTrailingNewline;
-use crate::ast::{cast, whitespace};
 use crate::checkers::ast::Checker;
 use crate::docstrings::definition::{DefinitionKind, Docstring};
 use crate::docstrings::sections::{section_contexts, SectionContext, SectionKind};
 use crate::docstrings::styles::SectionStyle;
-use crate::fix::Fix;
 use crate::message::Location;
-use crate::registry::{Diagnostic, Rule};
+use crate::registry::{AsRule, Rule};
 use crate::rules::pydocstyle::settings::Convention;
-use crate::violation::{AlwaysAutofixableViolation, Violation};
-use crate::visibility::is_staticmethod;
 
-define_violation!(
-    pub struct SectionNotOverIndented {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct SectionNotOverIndented {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for SectionNotOverIndented {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -39,11 +39,11 @@ impl AlwaysAutofixableViolation for SectionNotOverIndented {
     }
 }
 
-define_violation!(
-    pub struct SectionUnderlineNotOverIndented {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct SectionUnderlineNotOverIndented {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for SectionUnderlineNotOverIndented {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -57,11 +57,11 @@ impl AlwaysAutofixableViolation for SectionUnderlineNotOverIndented {
     }
 }
 
-define_violation!(
-    pub struct CapitalizeSectionName {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct CapitalizeSectionName {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for CapitalizeSectionName {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -75,11 +75,11 @@ impl AlwaysAutofixableViolation for CapitalizeSectionName {
     }
 }
 
-define_violation!(
-    pub struct NewLineAfterSectionName {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct NewLineAfterSectionName {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for NewLineAfterSectionName {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -93,11 +93,11 @@ impl AlwaysAutofixableViolation for NewLineAfterSectionName {
     }
 }
 
-define_violation!(
-    pub struct DashedUnderlineAfterSection {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct DashedUnderlineAfterSection {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for DashedUnderlineAfterSection {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -111,11 +111,11 @@ impl AlwaysAutofixableViolation for DashedUnderlineAfterSection {
     }
 }
 
-define_violation!(
-    pub struct SectionUnderlineAfterName {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct SectionUnderlineAfterName {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for SectionUnderlineAfterName {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -129,11 +129,11 @@ impl AlwaysAutofixableViolation for SectionUnderlineAfterName {
     }
 }
 
-define_violation!(
-    pub struct SectionUnderlineMatchesSectionLength {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct SectionUnderlineMatchesSectionLength {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for SectionUnderlineMatchesSectionLength {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -147,11 +147,11 @@ impl AlwaysAutofixableViolation for SectionUnderlineMatchesSectionLength {
     }
 }
 
-define_violation!(
-    pub struct BlankLineAfterSection {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct BlankLineAfterSection {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for BlankLineAfterSection {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -165,11 +165,11 @@ impl AlwaysAutofixableViolation for BlankLineAfterSection {
     }
 }
 
-define_violation!(
-    pub struct BlankLineBeforeSection {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct BlankLineBeforeSection {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for BlankLineBeforeSection {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -183,11 +183,11 @@ impl AlwaysAutofixableViolation for BlankLineBeforeSection {
     }
 }
 
-define_violation!(
-    pub struct BlankLineAfterLastSection {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct BlankLineAfterLastSection {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for BlankLineAfterLastSection {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -201,11 +201,11 @@ impl AlwaysAutofixableViolation for BlankLineAfterLastSection {
     }
 }
 
-define_violation!(
-    pub struct EmptyDocstringSection {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct EmptyDocstringSection {
+    pub name: String,
+}
+
 impl Violation for EmptyDocstringSection {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -214,11 +214,11 @@ impl Violation for EmptyDocstringSection {
     }
 }
 
-define_violation!(
-    pub struct SectionNameEndsInColon {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct SectionNameEndsInColon {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for SectionNameEndsInColon {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -232,11 +232,11 @@ impl AlwaysAutofixableViolation for SectionNameEndsInColon {
     }
 }
 
-define_violation!(
-    pub struct UndocumentedParam {
-        pub names: Vec<String>,
-    }
-);
+#[violation]
+pub struct UndocumentedParam {
+    pub names: Vec<String>,
+}
+
 impl Violation for UndocumentedParam {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -251,11 +251,11 @@ impl Violation for UndocumentedParam {
     }
 }
 
-define_violation!(
-    pub struct NoBlankLinesBetweenHeaderAndContent {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct NoBlankLinesBetweenHeaderAndContent {
+    pub name: String,
+}
+
 impl AlwaysAutofixableViolation for NoBlankLinesBetweenHeaderAndContent {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -273,7 +273,7 @@ impl AlwaysAutofixableViolation for NoBlankLinesBetweenHeaderAndContent {
 pub fn sections(checker: &mut Checker, docstring: &Docstring, convention: Option<&Convention>) {
     let body = docstring.body;
 
-    let lines: Vec<&str> = LinesWithTrailingNewline::from(body).collect();
+    let lines: Vec<&str> = NewlineWithTrailingNewline::from(body).collect();
     if lines.len() < 2 {
         return;
     }
@@ -294,18 +294,6 @@ pub fn sections(checker: &mut Checker, docstring: &Docstring, convention: Option
             // (e.g., "Returns", "Raises"). Break ties by checking for the presence of some of the
             // section names that are unique to each convention.
 
-            // If the docstring contains `Args:` or `Arguments:`, use the Google convention.
-            let google_sections = section_contexts(&lines, &SectionStyle::Google);
-            if google_sections
-                .iter()
-                .any(|context| matches!(context.kind, SectionKind::Arguments | SectionKind::Args))
-            {
-                for context in &google_sections {
-                    google_section(checker, docstring, context);
-                }
-                return;
-            }
-
             // If the docstring contains `Parameters:` or `Other Parameters:`, use the NumPy
             // convention.
             let numpy_sections = section_contexts(&lines, &SectionStyle::Numpy);
@@ -321,6 +309,18 @@ pub fn sections(checker: &mut Checker, docstring: &Docstring, convention: Option
                 return;
             }
 
+            // If the docstring contains `Args:` or `Arguments:`, use the Google convention.
+            let google_sections = section_contexts(&lines, &SectionStyle::Google);
+            if google_sections
+                .iter()
+                .any(|context| matches!(context.kind, SectionKind::Arguments | SectionKind::Args))
+            {
+                for context in &google_sections {
+                    google_section(checker, docstring, context);
+                }
+                return;
+            }
+
             // Otherwise, use whichever convention matched more sections.
             if google_sections.len() > numpy_sections.len() {
                 for context in &google_sections {
@@ -359,7 +359,7 @@ fn blanks_and_section_underline(
                 DashedUnderlineAfterSection {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Add a dashed line (of the appropriate length) under the section header.
@@ -384,7 +384,7 @@ fn blanks_and_section_underline(
                 EmptyDocstringSection {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             ));
         }
         return;
@@ -406,7 +406,7 @@ fn blanks_and_section_underline(
                     SectionUnderlineAfterName {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Delete any blank lines between the header and the underline.
@@ -444,7 +444,7 @@ fn blanks_and_section_underline(
                     SectionUnderlineMatchesSectionLength {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Replace the existing underline with a line of the appropriate length.
@@ -488,7 +488,7 @@ fn blanks_and_section_underline(
                     SectionUnderlineNotOverIndented {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Replace the existing indentation with whitespace of the appropriate length.
@@ -530,7 +530,7 @@ fn blanks_and_section_underline(
                             EmptyDocstringSection {
                                 name: context.section_name.to_string(),
                             },
-                            Range::from_located(docstring.expr),
+                            Range::from(docstring.expr),
                         ));
                     }
                 } else {
@@ -543,7 +543,7 @@ fn blanks_and_section_underline(
                             NoBlankLinesBetweenHeaderAndContent {
                                 name: context.section_name.to_string(),
                             },
-                            Range::from_located(docstring.expr),
+                            Range::from(docstring.expr),
                         );
                         if checker.patch(diagnostic.kind.rule()) {
                             // Delete any blank lines between the header and content.
@@ -575,7 +575,7 @@ fn blanks_and_section_underline(
                     EmptyDocstringSection {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 ));
             }
         }
@@ -589,7 +589,7 @@ fn blanks_and_section_underline(
                 DashedUnderlineAfterSection {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Add a dashed line (of the appropriate length) under the section header.
@@ -619,7 +619,7 @@ fn blanks_and_section_underline(
                     NoBlankLinesBetweenHeaderAndContent {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Delete any blank lines between the header and content.
@@ -651,7 +651,7 @@ fn common_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                 CapitalizeSectionName {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Replace the section title with the capitalized variant. This requires
@@ -688,7 +688,7 @@ fn common_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                 SectionNotOverIndented {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Replace the existing indentation with whitespace of the appropriate length.
@@ -721,7 +721,7 @@ fn common_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                     BlankLineAfterLastSection {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Add a newline after the section.
@@ -744,7 +744,7 @@ fn common_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                     BlankLineAfterSection {
                         name: context.section_name.to_string(),
                     },
-                    Range::from_located(docstring.expr),
+                    Range::from(docstring.expr),
                 );
                 if checker.patch(diagnostic.kind.rule()) {
                     // Add a newline after the section.
@@ -774,7 +774,7 @@ fn common_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                 BlankLineBeforeSection {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Add a blank line before the section.
@@ -796,7 +796,7 @@ fn missing_args(checker: &mut Checker, docstring: &Docstring, docstrings_args: &
         | DefinitionKind::NestedFunction(parent)
         | DefinitionKind::Method(parent)
     ) = docstring.kind else {
-        return
+        return;
     };
     let (
         StmtKind::FunctionDef {
@@ -806,7 +806,7 @@ fn missing_args(checker: &mut Checker, docstring: &Docstring, docstrings_args: &
             args: arguments, ..
         }
     ) = &parent.node else {
-        return
+        return;
     };
 
     // Look for arguments that weren't included in the docstring.
@@ -820,7 +820,7 @@ fn missing_args(checker: &mut Checker, docstring: &Docstring, docstrings_args: &
             // If this is a non-static method, skip `cls` or `self`.
             usize::from(
                 matches!(docstring.kind, DefinitionKind::Method(_))
-                    && !is_staticmethod(checker, cast::decorator_list(parent)),
+                    && !is_staticmethod(&checker.ctx, cast::decorator_list(parent)),
             ),
         )
     {
@@ -923,30 +923,32 @@ fn parameters_section(checker: &mut Checker, docstring: &Docstring, context: &Se
 
     // Join line continuations, then resplit by line.
     let adjusted_following_lines = context.following_lines.join("\n").replace("\\\n", "");
-    let lines: Vec<&str> = LinesWithTrailingNewline::from(&adjusted_following_lines).collect();
-
-    for i in 1..lines.len() {
-        let current_line = lines[i - 1];
-        let current_leading_space = whitespace::leading_space(current_line);
-        let next_line = lines[i];
-        if current_leading_space == section_level_indent
-            && (whitespace::leading_space(next_line).len() > current_leading_space.len())
-            && !next_line.trim().is_empty()
-        {
-            let parameters = if let Some(semi_index) = current_line.find(':') {
-                // If the parameter has a type annotation, exclude it.
-                &current_line[..semi_index]
-            } else {
-                // Otherwise, it's just a list of parameters on the current line.
-                current_line.trim()
-            };
-            // Notably, NumPy lets you put multiple parameters of the same type on the same
-            // line.
-            for parameter in parameters.split(',') {
-                docstring_args.insert(parameter.trim());
+    let mut lines = NewlineWithTrailingNewline::from(&adjusted_following_lines);
+    if let Some(mut current_line) = lines.next() {
+        for next_line in lines {
+            let current_leading_space = whitespace::leading_space(current_line);
+            if current_leading_space == section_level_indent
+                && (whitespace::leading_space(next_line).len() > current_leading_space.len())
+                && !next_line.trim().is_empty()
+            {
+                let parameters = if let Some(semi_index) = current_line.find(':') {
+                    // If the parameter has a type annotation, exclude it.
+                    &current_line[..semi_index]
+                } else {
+                    // Otherwise, it's just a list of parameters on the current line.
+                    current_line.trim()
+                };
+                // Notably, NumPy lets you put multiple parameters of the same type on the same
+                // line.
+                for parameter in parameters.split(',') {
+                    docstring_args.insert(parameter.trim());
+                }
             }
+
+            current_line = next_line;
         }
     }
+
     // Validate that all arguments were documented.
     missing_args(checker, docstring, &docstring_args);
 }
@@ -969,7 +971,7 @@ fn numpy_section(checker: &mut Checker, docstring: &Docstring, context: &Section
                 NewLineAfterSectionName {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Delete the suffix. This requires locating the end of the section name.
@@ -1020,7 +1022,7 @@ fn google_section(checker: &mut Checker, docstring: &Docstring, context: &Sectio
                 SectionNameEndsInColon {
                     name: context.section_name.to_string(),
                 },
-                Range::from_located(docstring.expr),
+                Range::from(docstring.expr),
             );
             if checker.patch(diagnostic.kind.rule()) {
                 // Replace the suffix. This requires locating the end of the section name.
