@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Expr, ExprKind, Stmt};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct IfTuple;
 
-define_violation!(
-    pub struct IfTuple;
-);
 impl Violation for IfTuple {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -22,7 +22,7 @@ pub fn if_tuple(checker: &mut Checker, stmt: &Stmt, test: &Expr) {
         if !elts.is_empty() {
             checker
                 .diagnostics
-                .push(Diagnostic::new(IfTuple, Range::from_located(stmt)));
+                .push(Diagnostic::new(IfTuple, Range::from(stmt)));
         }
     }
 }
