@@ -1,14 +1,13 @@
-use ruff_macros::{define_violation, derive_message_formats};
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
 
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
 
-define_violation!(
-    pub struct UnusedAnnotation {
-        pub name: String,
-    }
-);
+#[violation]
+pub struct UnusedAnnotation {
+    pub name: String,
+}
+
 impl Violation for UnusedAnnotation {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -19,11 +18,11 @@ impl Violation for UnusedAnnotation {
 
 /// F842
 pub fn unused_annotation(checker: &mut Checker, scope: usize) {
-    let scope = &checker.scopes[scope];
+    let scope = &checker.ctx.scopes[scope];
     for (name, binding) in scope
         .bindings
         .iter()
-        .map(|(name, index)| (name, &checker.bindings[*index]))
+        .map(|(name, index)| (name, &checker.ctx.bindings[*index]))
     {
         if !binding.used()
             && binding.kind.is_annotation()
