@@ -1,51 +1,51 @@
 use itertools::Itertools;
 use log::error;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{ExprKind, Located, Stmt, StmtKind};
 use rustpython_parser::{lexer, Mode, Tok};
 
-use crate::ast::helpers::contains_effect;
-use crate::ast::types::{Range, RefEquality, ScopeKind};
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::helpers::contains_effect;
+use ruff_python_ast::source_code::Locator;
+use ruff_python_ast::types::{Range, RefEquality, ScopeKind};
+
 use crate::autofix::helpers::delete_stmt;
 use crate::checkers::ast::Checker;
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
-use crate::source_code::Locator;
-use crate::violation::AlwaysAutofixableViolation;
+use crate::registry::AsRule;
+
+/// ## What it does
+/// Checks for the presence of unused variables in function scopes.
+///
+/// ## Why is this bad?
+/// A variable that is defined but not used is likely a mistake, and should
+/// be removed to avoid confusion.
+///
+/// If a variable is intentionally defined-but-not-used, it should be
+/// prefixed with an underscore, or some other value that adheres to the
+/// [`dummy-variable-rgx`] pattern.
+///
+/// ## Options
+/// - `dummy-variable-rgx`
+///
+/// ## Example
+/// ```python
+/// def foo():
+///     x = 1
+///     y = 2
+///     return x
+/// ```
+///
+/// Use instead:
+/// ```python
+/// def foo():
+///     x = 1
+///     return x
+/// ```
+#[violation]
+pub struct UnusedVariable {
+    pub name: String,
+}
 
-define_violation!(
-    /// ## What it does
-    /// Checks for the presence of unused variables in function scopes.
-    ///
-    /// ## Why is this bad?
-    /// A variable that is defined but not used is likely a mistake, and should
-    /// be removed to avoid confusion.
-    ///
-    /// If a variable is intentionally defined-but-not-used, it should be
-    /// prefixed with an underscore, or some other value that adheres to the
-    /// [`dummy-variable-rgx`] pattern.
-    ///
-    /// ## Options
-    /// - `dummy-variable-rgx`
-    ///
-    /// ## Example
-    /// ```python
-    /// def foo():
-    ///     x = 1
-    ///     y = 2
-    ///     return x
-    /// ```
-    ///
-    /// Use instead:
-    /// ```python
-    /// def foo():
-    ///     x = 1
-    ///     return x
-    /// ```
-    pub struct UnusedVariable {
-        pub name: String,
-    }
-);
 impl AlwaysAutofixableViolation for UnusedVariable {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -200,7 +200,7 @@ fn remove_unused_variable(
             range.location == target.location && range.end_location == target.end_location.unwrap()
         }) {
             if matches!(target.node, ExprKind::Name { .. }) {
-                return if targets.len() > 1 || contains_effect(checker, value) {
+                return if targets.len() > 1 || contains_effect(&checker.ctx, value) {
                     // If the expression is complex (`x = foo()`), remove the assignment,
                     // but preserve the right-hand side.
                     Some((
@@ -214,14 +214,11 @@ fn remove_unused_variable(
                 } else {
                     // If (e.g.) assigning to a constant (`x = 1`), delete the entire statement.
                     let parent = checker
+                        .ctx
                         .child_to_parent
                         .get(&RefEquality(stmt))
-                        .map(std::convert::Into::into);
-                    let deleted: Vec<&Stmt> = checker
-                        .deletions
-                        .iter()
-                        .map(std::convert::Into::into)
-                        .collect();
+                        .map(Into::into);
+                    let deleted: Vec<&Stmt> = checker.deletions.iter().map(Into::into).collect();
                     match delete_stmt(
                         stmt,
                         parent,
@@ -249,7 +246,7 @@ fn remove_unused_variable(
     } = &stmt.node
     {
         if matches!(target.node, ExprKind::Name { .. }) {
-            return if contains_effect(checker, value) {
+            return if contains_effect(&checker.ctx, value) {
                 // If the expression is complex (`x = foo()`), remove the assignment,
                 // but preserve the right-hand side.
                 Some((
@@ -262,14 +259,11 @@ fn remove_unused_variable(
             } else {
                 // If assigning to a constant (`x = 1`), delete the entire statement.
                 let parent = checker
+                    .ctx
                     .child_to_parent
                     .get(&RefEquality(stmt))
-                    .map(std::convert::Into::into);
-                let deleted: Vec<&Stmt> = checker
-                    .deletions
-                    .iter()
-                    .map(std::convert::Into::into)
-                    .collect();
+                    .map(Into::into);
+                let deleted: Vec<&Stmt> = checker.deletions.iter().map(Into::into).collect();
                 match delete_stmt(
                     stmt,
                     parent,
@@ -319,7 +313,7 @@ fn remove_unused_variable(
 
 /// F841
 pub fn unused_variable(checker: &mut Checker, scope: usize) {
-    let scope = &checker.scopes[scope];
+    let scope = &checker.ctx.scopes[scope];
     if scope.uses_locals && matches!(scope.kind, ScopeKind::Function(..)) {
         return;
     }
@@ -327,7 +321,7 @@ pub fn unused_variable(checker: &mut Checker, scope: usize) {
     for (name, binding) in scope
         .bindings
         .iter()
-        .map(|(name, index)| (name, &checker.bindings[*index]))
+        .map(|(name, index)| (name, &checker.ctx.bindings[*index]))
     {
         if !binding.used()
             && binding.kind.is_assignment()
@@ -343,7 +337,7 @@ pub fn unused_variable(checker: &mut Checker, scope: usize) {
                 binding.range,
             );
             if checker.patch(diagnostic.kind.rule()) {
-                if let Some(stmt) = binding.source.as_ref().map(std::convert::Into::into) {
+                if let Some(stmt) = binding.source.as_ref().map(Into::into) {
                     if let Some((kind, fix)) = remove_unused_variable(stmt, &binding.range, checker)
                     {
                         if matches!(kind, DeletionKind::Whole) {
