@@ -212,11 +212,13 @@ const TYPING_TO_RENAME_PY39: &[(&str, &str)] = &[
         "AsyncContextManager",
         "contextlib.AbstractAsyncContextManager",
     ),
+    ("ContextManager", "contextlib.AbstractContextManager"),
     ("AbstractSet", "collections.abc.Set"),
     ("Tuple", "tuple"),
     ("List", "list"),
     ("FrozenSet", "frozenset"),
     ("Dict", "dict"),
+    ("Type", "type"),
     ("Set", "set"),
     ("Deque", "collections.deque"),
     ("DefaultDict", "collections.defaultdict"),
