@@ -1,4 +1,3 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustc_hash::FxHashMap;
 use rustpython_common::format::{
     FieldName, FieldNamePart, FieldType, FormatPart, FormatString, FromTemplate,
@@ -6,18 +5,19 @@ use rustpython_common::format::{
 use rustpython_parser::ast::{Constant, Expr, ExprKind, KeywordData};
 use rustpython_parser::{lexer, Mode, Tok};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::str::{leading_quote, trailing_quote};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::fix::Fix;
-use crate::registry::Diagnostic;
-use crate::rules::pydocstyle::helpers::{leading_quote, trailing_quote};
+use crate::registry::AsRule;
 use crate::rules::pyflakes::format::FormatSummary;
 use crate::rules::pyupgrade::helpers::curly_escape;
-use crate::violation::AlwaysAutofixableViolation;
 
-define_violation!(
-    pub struct FString;
-);
+#[violation]
+pub struct FString;
+
 impl AlwaysAutofixableViolation for FString {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -45,7 +45,7 @@ impl<'a> FormatSummaryValues<'a> {
         let mut extracted_kwargs: FxHashMap<&str, String> = FxHashMap::default();
         if let ExprKind::Call { args, keywords, .. } = &expr.node {
             for arg in args {
-                let arg = checker.locator.slice(&Range::from_located(arg));
+                let arg = checker.locator.slice(arg);
                 if contains_invalids(arg) {
                     return None;
                 }
@@ -54,7 +54,7 @@ impl<'a> FormatSummaryValues<'a> {
             for keyword in keywords {
                 let KeywordData { arg, value } = &keyword.node;
                 if let Some(key) = arg {
-                    let kwarg = checker.locator.slice(&Range::from_located(value));
+                    let kwarg = checker.locator.slice(value);
                     if contains_invalids(kwarg) {
                         return None;
                     }
@@ -125,7 +125,7 @@ fn try_convert_to_f_string(checker: &Checker, expr: &Expr) -> Option<String> {
         return None;
     };
 
-    let contents = checker.locator.slice(&Range::from_located(value));
+    let contents = checker.locator.slice(value);
 
     // Tokenize: we need to avoid trying to fix implicit string concatenations.
     if lexer::lex(contents, Mode::Module)
@@ -258,12 +258,12 @@ pub(crate) fn f_strings(checker: &mut Checker, summary: &FormatSummary, expr: &E
     };
 
     // Avoid refactors that increase the resulting string length.
-    let existing = checker.locator.slice(&Range::from_located(expr));
+    let existing = checker.locator.slice(expr);
     if contents.len() > existing.len() {
         return;
     }
 
-    let mut diagnostic = Diagnostic::new(FString, Range::from_located(expr));
+    let mut diagnostic = Diagnostic::new(FString, Range::from(expr));
     if checker.patch(diagnostic.kind.rule()) {
         diagnostic.amend(Fix::replacement(
             contents,
