@@ -1,22 +1,22 @@
 use once_cell::sync::Lazy;
-use ruff_macros::{define_violation, derive_message_formats};
 use rustc_hash::FxHashMap;
 
-use crate::ast::types::Range;
-use crate::fix::Fix;
+use ruff_diagnostics::{AlwaysAutofixableViolation, Diagnostic, DiagnosticKind, Fix};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::source_code::Locator;
+use ruff_python_ast::types::Range;
+
 use crate::message::Location;
-use crate::registry::{Diagnostic, DiagnosticKind};
+use crate::registry::AsRule;
 use crate::rules::ruff::rules::Context;
 use crate::settings::{flags, Settings};
-use crate::source_code::Locator;
-use crate::violation::AlwaysAutofixableViolation;
 
-define_violation!(
-    pub struct AmbiguousUnicodeCharacterString {
-        pub confusable: char,
-        pub representant: char,
-    }
-);
+#[violation]
+pub struct AmbiguousUnicodeCharacterString {
+    pub confusable: char,
+    pub representant: char,
+}
+
 impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterString {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -39,12 +39,12 @@ impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterString {
     }
 }
 
-define_violation!(
-    pub struct AmbiguousUnicodeCharacterDocstring {
-        pub confusable: char,
-        pub representant: char,
-    }
-);
+#[violation]
+pub struct AmbiguousUnicodeCharacterDocstring {
+    pub confusable: char,
+    pub representant: char,
+}
+
 impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterDocstring {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -67,12 +67,12 @@ impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterDocstring {
     }
 }
 
-define_violation!(
-    pub struct AmbiguousUnicodeCharacterComment {
-        pub confusable: char,
-        pub representant: char,
-    }
-);
+#[violation]
+pub struct AmbiguousUnicodeCharacterComment {
+    pub confusable: char,
+    pub representant: char,
+}
+
 impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterComment {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -96,7 +96,7 @@ impl AlwaysAutofixableViolation for AmbiguousUnicodeCharacterComment {
 }
 
 /// See: <https://github.com/microsoft/vscode/blob/095ddabc52b82498ee7f718a34f9dd11d59099a8/src/vs/base/common/strings.ts#L1094>
-static CONFUSABLES: Lazy<FxHashMap<u32, u32>> = Lazy::new(|| {
+static CONFUSABLES: Lazy<FxHashMap<u32, u8>> = Lazy::new(|| {
     #[allow(clippy::unreadable_literal)]
     FxHashMap::from_iter([
         (8232, 32),
@@ -1693,7 +1693,7 @@ pub fn ambiguous_unicode_character(
 ) -> Vec<Diagnostic> {
     let mut diagnostics = vec![];
 
-    let text = locator.slice(&Range::new(start, end));
+    let text = locator.slice(Range::new(start, end));
 
     let mut col_offset = 0;
     let mut row_offset = 0;
@@ -1701,44 +1701,42 @@ pub fn ambiguous_unicode_character(
         // Search for confusing characters.
         if let Some(representant) = CONFUSABLES.get(&(current_char as u32)) {
             if !settings.allowed_confusables.contains(&current_char) {
-                if let Some(representant) = char::from_u32(*representant) {
-                    let col = if row_offset == 0 {
-                        start.column() + col_offset
-                    } else {
-                        col_offset
-                    };
-                    let location = Location::new(start.row() + row_offset, col);
-                    let end_location = Location::new(location.row(), location.column() + 1);
-                    let mut diagnostic = Diagnostic::new::<DiagnosticKind>(
-                        match context {
-                            Context::String => AmbiguousUnicodeCharacterString {
-                                confusable: current_char,
-                                representant,
-                            }
-                            .into(),
-                            Context::Docstring => AmbiguousUnicodeCharacterDocstring {
-                                confusable: current_char,
-                                representant,
-                            }
-                            .into(),
-                            Context::Comment => AmbiguousUnicodeCharacterComment {
-                                confusable: current_char,
-                                representant,
-                            }
-                            .into(),
-                        },
-                        Range::new(location, end_location),
-                    );
-                    if settings.rules.enabled(diagnostic.kind.rule()) {
-                        if autofix.into() && settings.rules.should_fix(diagnostic.kind.rule()) {
-                            diagnostic.amend(Fix::replacement(
-                                representant.to_string(),
-                                location,
-                                end_location,
-                            ));
+                let col = if row_offset == 0 {
+                    start.column() + col_offset
+                } else {
+                    col_offset
+                };
+                let location = Location::new(start.row() + row_offset, col);
+                let end_location = Location::new(location.row(), location.column() + 1);
+                let mut diagnostic = Diagnostic::new::<DiagnosticKind>(
+                    match context {
+                        Context::String => AmbiguousUnicodeCharacterString {
+                            confusable: current_char,
+                            representant: *representant as char,
                         }
-                        diagnostics.push(diagnostic);
+                        .into(),
+                        Context::Docstring => AmbiguousUnicodeCharacterDocstring {
+                            confusable: current_char,
+                            representant: *representant as char,
+                        }
+                        .into(),
+                        Context::Comment => AmbiguousUnicodeCharacterComment {
+                            confusable: current_char,
+                            representant: *representant as char,
+                        }
+                        .into(),
+                    },
+                    Range::new(location, end_location),
+                );
+                if settings.rules.enabled(diagnostic.kind.rule()) {
+                    if autofix.into() && settings.rules.should_fix(diagnostic.kind.rule()) {
+                        diagnostic.amend(Fix::replacement(
+                            (*representant as char).to_string(),
+                            location,
+                            end_location,
+                        ));
                     }
+                    diagnostics.push(diagnostic);
                 }
             }
         }
