@@ -5,6 +5,7 @@ pub use raise_vanilla_class::{raise_vanilla_class, RaiseVanillaClass};
 pub use raise_within_try::{raise_within_try, RaiseWithinTry};
 pub use reraise_no_cause::{reraise_no_cause, ReraiseNoCause};
 pub use try_consider_else::{try_consider_else, TryConsiderElse};
+pub use verbose_log_message::{verbose_log_message, VerboseLogMessage};
 pub use verbose_raise::{verbose_raise, VerboseRaise};
 
 mod error_instead_of_exception;
@@ -14,4 +15,5 @@ mod raise_vanilla_class;
 mod raise_within_try;
 mod reraise_no_cause;
 mod try_consider_else;
+mod verbose_log_message;
 mod verbose_raise;
