@@ -1,14 +1,14 @@
-use ruff_macros::{define_violation, derive_message_formats};
 use rustpython_parser::ast::{Stmt, StmtKind};
 
-use crate::ast::types::Range;
+use ruff_diagnostics::{Diagnostic, Violation};
+use ruff_macros::{derive_message_formats, violation};
+use ruff_python_ast::types::Range;
+
 use crate::checkers::ast::Checker;
-use crate::registry::Diagnostic;
-use crate::violation::Violation;
+
+#[violation]
+pub struct TryConsiderElse;
 
-define_violation!(
-    pub struct TryConsiderElse;
-);
 impl Violation for TryConsiderElse {
     #[derive_message_formats]
     fn message(&self) -> String {
@@ -23,7 +23,7 @@ pub fn try_consider_else(checker: &mut Checker, body: &[Stmt], orelse: &[Stmt])
             if let StmtKind::Return { .. } = &stmt.node {
                 checker
                     .diagnostics
-                    .push(Diagnostic::new(TryConsiderElse, Range::from_located(stmt)));
+                    .push(Diagnostic::new(TryConsiderElse, Range::from(stmt)));
             }
         }
     }
